@@ -15,9 +15,6 @@
 
 """A module that converts API exceptions to core exceptions."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import collections
 import io
