@@ -14,9 +14,6 @@
 # limitations under the License.
 """Flags and helpers for the compute organization firewall policies commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.command_lib.compute import completers as compute_completers
@@ -546,7 +543,7 @@ def AddSrcRegionCodes(parser, support_network_scopes=False):
   if support_network_scopes:
     help_text += (
         'Cannot be specified when the source network'
-        ' type is NON_INTERNET, VPC_NETWORK or INTRA_VPC. '
+        ' context is NON_INTERNET, VPC_NETWORK or INTRA_VPC. '
     )
   parser.add_argument(
       '--src-region-codes',
@@ -565,7 +562,7 @@ def AddDestRegionCodes(parser, support_network_scopes=False):
   )
   if support_network_scopes:
     help_text += (
-        'Cannot be specified when the source network type is NON_INTERNET. '
+        'Cannot be specified when the source network context is NON_INTERNET. '
     )
   parser.add_argument(
       '--dest-region-codes',
@@ -588,7 +585,7 @@ def AddSrcThreatIntelligence(parser, support_network_scopes=False):
     text_help = (
         'Source Threat Intelligence lists to match for this rule. '
         'Can only be specified if DIRECTION is `ingress`. Cannot be specified'
-        ' when the source network type is NON_INTERNET, VPC_NETWORK or'
+        ' when the source network context is NON_INTERNET, VPC_NETWORK or'
         ' INTRA_VPC. '
         'The available lists can be found here: '
         'https://cloud.google.com/vpc/docs/firewall-policies-rule-details#threat-intelligence-fw-policy.'
@@ -614,7 +611,7 @@ def AddDestThreatIntelligence(parser, support_network_scopes=False):
     text_help = (
         'Destination Threat Intelligence lists to match for this rule. '
         'Can only be specified if DIRECTION is `egress`. Cannot be specified'
-        ' when source network type is NON_INTERNET. '
+        ' when source network context is NON_INTERNET. '
         'The available lists can be found here: '
         'https://cloud.google.com/vpc/docs/firewall-policies-rule-details#threat-intelligence-fw-policy.'
     )
