@@ -14,9 +14,6 @@
 # limitations under the License.
 """Helpers for flags in commands working with Google Cloud Functions."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import json
 
@@ -467,7 +464,7 @@ def AddStageBucketFlag(parser):
   )
 
 
-def AddRuntimeFlag(parser):
+def AddRuntimeFlag(parser, hidden=False):
   parser.add_argument(
       '--runtime',
       help="""\
@@ -478,6 +475,7 @@ def AddRuntimeFlag(parser):
 
           For a list of available runtimes, run `gcloud functions runtimes list`.
           """,
+      hidden=hidden,
   )
 
 
@@ -538,7 +536,6 @@ def _AddVpcNetworkFlag(parser):
           ' subnetwork of the network specified by this --network flag. To'
           ' clear existing VPC network settings, use --clear-network.'
       ),
-      hidden=True,
   )
 
 
@@ -554,7 +551,6 @@ def _AddVpcSubnetFlag(parser):
           ' looked up from this subnetwork. To clear existing VPC network'
           ' settings, use --clear-network.'
       ),
-      hidden=True,
   )
 
 
@@ -569,7 +565,6 @@ def _AddVpcNetworkTagsFlag(parser):
           'Cloud Function. '
           'To clear existing tags, use --clear-network-tags.'
       ),
-      hidden=True,
   )
 
 
@@ -581,7 +576,6 @@ def _AddClearVpcNetworkTagsFlag(parser):
       help=(
           'Clears all existing network tags from the Cloud Function.'
       ),
-      hidden=True,
   )
 
 
@@ -592,9 +586,9 @@ def _AddDirectVpcEgressFlag(parser):
       choices=[x.lower() for x in EGRESS_SETTINGS],
       help_str=(
           'Specify which of the outbound traffic to send through Direct VPC'
-          ' egress. Configuring DirectVPC network is required to use this flag.'
+          ' egress. Configuring Direct VPC network is required to use this'
+          ' flag.'
       ),
-      hidden=True,
   )
   direct_vpc_egress_arg.AddToParser(parser)
 
@@ -602,12 +596,12 @@ def _AddDirectVpcEgressFlag(parser):
 def _AddNetworkInterfaceGroupFlags(parser):
   """Add flag for specifying Direct VPC network interface to the parser."""
   group = parser.add_argument_group(
-      'Direct VPC egress setting flags group.', hidden=True
+      'Direct VPC egress setting flags group.'
   )
   _AddVpcNetworkFlag(group)
   _AddVpcSubnetFlag(group)
 
-  tags_group = group.add_group(mutex=True, hidden=True)
+  tags_group = group.add_group(mutex=True)
   _AddVpcNetworkTagsFlag(tags_group)
   _AddClearVpcNetworkTagsFlag(tags_group)
 
@@ -621,13 +615,12 @@ def _AddClearVpcNetworkFlag(parser):
           'Disconnect this Cloud Function from the Direct VPC network it is'
           ' connected to.'
       ),
-      hidden=True,
   )
 
 
 def AddAllDirectVpcFlags(parser):
   """Add flags for all Direct VPC network related settings."""
-  ni_group = parser.add_group(mutex=True, hidden=True)
+  ni_group = parser.add_group(mutex=True)
   _AddNetworkInterfaceGroupFlags(ni_group)
   _AddClearVpcNetworkFlag(ni_group)
 
@@ -1197,19 +1190,26 @@ def AddConcurrencyFlag(parser):
   )
 
 
-def AddUpgradeFlags(parser):
+def AddUpgradeFlags(parser, release_track=base.ReleaseTrack.GA):
   """Adds upgrade related function flags."""
+  if release_track == base.ReleaseTrack.ALPHA:
+    description = 'Upgrade a 1st gen Cloud Function to a Cloud Run Function.'
+    commit_flag_help = '- `--commit` and optionally `--skip-detach`'
+  else:
+    description = 'Upgrade a 1st gen Cloud Function to the 2nd gen environment.'
+    commit_flag_help = '- `--commit`'
+
   upgrade_group = parser.add_group(
       mutex=True,
       help="""\
-      Upgrade a 1st gen Cloud Function to the 2nd gen environment.
+      {}
       You must specify one of the following flags:
       - `--setup-config` and optionally `--trigger-service-account`,
       - `--redirect-traffic`,
       - `--rollback-traffic`,
-      - `--commit`,
+      {},
       - `--abort`.
-  """,
+  """.format(description, commit_flag_help),
   )
 
   setup_config_group = upgrade_group.add_argument_group()
@@ -1222,6 +1222,18 @@ def AddUpgradeFlags(parser):
       ),
   )
   AddTriggerServiceAccountFlag(setup_config_group)
+  if release_track in (base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA):
+    hidden = release_track == base.ReleaseTrack.BETA
+    AddRuntimeFlag(setup_config_group, hidden=hidden)
+    setup_config_group.add_argument(
+        '--max-instances',
+        type=arg_parsers.BoundedInt(lower_bound=1),
+        help="""\
+          Sets the maximum number of instances for the function. A function
+          execution that would exceed max-instances times out.
+        """,
+        hidden=hidden,
+    )
 
   upgrade_group.add_argument(
       '--redirect-traffic',
@@ -1236,7 +1248,9 @@ def AddUpgradeFlags(parser):
           ' function. The 2nd gen copy will still be available for testing.'
       ),
   )
-  upgrade_group.add_argument(
+
+  commit_group = upgrade_group.add_argument_group()
+  commit_group.add_argument(
       '--commit',
       action='store_true',
       help=(
@@ -1244,6 +1258,20 @@ def AddUpgradeFlags(parser):
           ' 1st gen copy of the function.'
       ),
   )
+  if release_track == base.ReleaseTrack.ALPHA:
+    commit_group.add_argument(
+        '--skip-detach',
+        action='store_true',
+        hidden=True,
+        help=(
+            'The function will not be detached when committing the upgrade to'
+            ' allow continued use of the Cloud Functions v2 API. You can'
+            ' detach the function to Cloud Run afterward'
+            ' https://docs.cloud.google.com/run/docs/functions/comparison#detach_your_function.'
+            ' This flag is only valid when used with --commit flag.'
+        ),
+    )
+
   upgrade_group.add_argument(
       '--abort',
       action='store_true',
